library(sfsGrading)

## Test applyGrading():
## INPUT: pointsTotal (vector), gradeFn (function), settings (list for gradeFn)
## also test: 
## - gradesLinear
## - gradesPiecewiseLinear
## - gradesPiecewiseLinearIntercept

## Using gradesLinear
pointsTotal_L_1 <- 1:6
settings_L_1 <- list(pointsFor4 = 4, pointsFor6 = 6)
gr1 <- applyGrading(pointsTotal = pointsTotal_L_1, 
                    gradeFn = gradesLinear,
                    settings = settings_L_1)
stopifnot(all(gr1[,"rawGrade"] == 1:6), 
          all(gr1[,"grade"] == 1:6))

pointsTotal_L_2 <- 1:12
settings_L_2 <- list(pointsFor4 = 8, pointsFor6 = 12)
gr2 <- applyGrading(pointsTotal = pointsTotal_L_2, 
                    gradeFn = gradesLinear,
                    settings = settings_L_2)
stopifnot(all(gr2[,"rawGrade"] == seq(0.5,6,by=0.5)), 
          all(gr2[,"grade"] == c(1,1,1.5,2,2.5,3,3.5,4,4.5,5,5.5,6)))

## Using gradesPiecewiseLinear
pointsTotal_PL_1 <- 0:6
settings_PL_1 <- list(pointsFor4 = 4, pointsFor6 = 6)
gr3 <- applyGrading(pointsTotal = pointsTotal_PL_1, 
                    gradeFn = gradesPiecewiseLinear,
                    settings = settings_PL_1)
stopifnot(all(gr3[,"rawGrade"] == c(1, 1.75, 2.5, 3.25, 4, 5, 6)), 
          all(gr3[,"grade"] == c(1, 1.75, 2.5, 3.25, 4, 5, 6)))

pointsTotal_PL_2 <- 0:12
settings_PL_2 <- list(pointsFor4 = 8, pointsFor6 = 12)
gr4 <- applyGrading(pointsTotal = pointsTotal_PL_2, 
                    gradeFn = gradesPiecewiseLinear,
                    settings = settings_PL_2)
stopifnot(all(gr4[,"rawGrade"] == c(1,1.375,1.75,2.125,2.5,2.875,3.25,3.625,4,4.5,5,5.5,6)), 
          all(gr4[,"grade"] == c(1,1.5,1.75,2.25,2.5,3,3.25,3.75,4,4.5,5,5.5,6)))

## Using gradesPiecewiseLinearIntercept
pointsTotal_PLI_1 <- 0:12
settings_PLI_1 <- list(pointsFor1 = 2, pointsFor4 = 8, pointsFor6 = 12)
gr5 <- applyGrading(pointsTotal = pointsTotal_PLI_1, 
                    gradeFn = gradesPiecewiseLinearIntercept,
                    settings = settings_PLI_1)
gr5
stopifnot(all(gr5[,"rawGrade"] == c(1,1,seq(1,6,by=0.5))), 
          all(gr5[,"grade"] == c(1,1,seq(1,6,by=0.5))))
